==> okta-sdk-api-21.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/AuthorizationServerPolicyConditions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.ClientPolicyCondition;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * AuthorizationServerPolicyConditions
 */
@JsonPropertyOrder({ AuthorizationServerPolicyConditions.JSON_PROPERTY_CLIENTS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class AuthorizationServerPolicyConditions implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CLIENTS = "clients";
    private ClientPolicyCondition clients;

    public AuthorizationServerPolicyConditions() {
    }

    public AuthorizationServerPolicyConditions clients(ClientPolicyCondition clients) {

        this.clients = clients;
        return this;
    }

    /**
     * Get clients
     *
     * @return clients
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CLIENTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public ClientPolicyCondition getClients() {
        return clients;
    }

    @JsonProperty(JSON_PROPERTY_CLIENTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setClients(ClientPolicyCondition clients) {
        this.clients = clients;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AuthorizationServerPolicyConditions authorizationServerPolicyConditions = (AuthorizationServerPolicyConditions) o;
        return Objects.equals(this.clients, authorizationServerPolicyConditions.clients);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(clients);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AuthorizationServerPolicyConditions {\n");
        sb.append("    clients: ").append(toIndentedString(clients)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/AuthorizationServerPolicyConditions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.ClientPolicyCondition;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * AuthorizationServerPolicyConditions
 */
@JsonPropertyOrder({ AuthorizationServerPolicyConditions.JSON_PROPERTY_CLIENTS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class AuthorizationServerPolicyConditions implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CLIENTS = "clients";
    private ClientPolicyCondition clients;

    public AuthorizationServerPolicyConditions() {
    }

    public AuthorizationServerPolicyConditions clients(ClientPolicyCondition clients) {

        this.clients = clients;
        return this;
    }

    /**
     * Get clients
     *
     * @return clients
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CLIENTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public ClientPolicyCondition getClients() {
        return clients;
    }

    @JsonProperty(JSON_PROPERTY_CLIENTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setClients(ClientPolicyCondition clients) {
        this.clients = clients;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AuthorizationServerPolicyConditions authorizationServerPolicyConditions = (AuthorizationServerPolicyConditions) o;
        return Objects.equals(this.clients, authorizationServerPolicyConditions.clients);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(clients);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AuthorizationServerPolicyConditions {\n");
        sb.append("    clients: ").append(toIndentedString(clients)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
